==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/ls/hls32_dbextract.h <==
/*!**********************************************************************

  module: hls32_dbextract.h

  -----------------------------------------------------------------------

  responsible:  Hans-GeorgB
  special area: 
  description:
  version    : 7.3
  see also:

  -----------------------------------------------------------------------

   ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end
*/

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#ifndef HLS32_DBEXTRACT
#define HLS32_DBEXTRACT

#include "gls00.h"

/*!
  -----------------------------------------------------------------------------

  function:     ls32ExecDBExtract

  -----------------------------------------------------------------------------

  description:  DBExtract main function

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
				pDBExtrCmd  [IN]    - A pointer to a structure that contains all
                                      information on the catalogextract command given
                                      by the user
                errText     [OUT]   - A pointer to a buffer where a description is
                                      available in case of errors
  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors

  -----------------------------------------------------------------------------
*/
tsp00_Int4 ls32ExecDBExtract ( tls00_DBExtrCmd * pDBExtrCmd, tls00_DBInfo *pDBInfo, tsp00_Addr ErrText);

/*!
  -----------------------------------------------------------------------------

  function:     ls32ExecDBLoad

  -----------------------------------------------------------------------------

  description:  DBLoad main function

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
				pDBLoadCmd  [IN]    - A pointer to a structure that contains all
                                      information on the catalogextract command given
                                      by the user
                errText     [OUT]   - A pointer to a buffer where a description is
                                      available in case of errors
  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors

  -----------------------------------------------------------------------------
*/
tsp00_Int4 ls32ExecDBLoad   ( tls00_DBLoadCmd * pDBLoadCmd, tls00_DBInfo *pDBInfo, tsp00_Addr ErrText);


#endif //HLS32_DBEXTRACT

/*===========================================================================*
 *     END
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/ls/hls32_dbextract.h <==
/*!**********************************************************************

  module: hls32_dbextract.h

  -----------------------------------------------------------------------

  responsible:  d033893

  special area: SAP DB LOADER

  description:

  version    : 7.4

  see also:

  -----------------------------------------------------------------------


      ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#ifndef HLS32_DBEXTRACT
#define HLS32_DBEXTRACT

#include "gls00.h"


/*!
  -----------------------------------------------------------------------------

  function:     ls32ExecDatabaseTransformation

  -----------------------------------------------------------------------------

  description:  

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
				pTransformationCmd[IN]    
				                    - A pointer to a structure that contains all
                                      information on the catalogextract/catalogextract
									  command givenby the user
                errText     [OUT]   - A pointer to a buffer where a description is
                                      available in case of errors
  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors

  -----------------------------------------------------------------------------
*/
SAPDB_Int4 ls32ExecDatabaseTransformation( tls00_Command    *pTransformationCmd, 
								           tls00_DBInfo     *pDBInfo,
								           tsp00_Addr        ErrText);

/*!
  -----------------------------------------------------------------------------

  function:     ls32ExecDBTransformation

  -----------------------------------------------------------------------------

  description:  

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
				pTransformationCmd[IN]    
				                    - A pointer to a structure that contains all
                                      information on the catalogextract/catalogextract
									  command givenby the user
                errText     [OUT]   - A pointer to a buffer where a description is
                                      available in case of errors
  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors

  -----------------------------------------------------------------------------
*/
SAPDB_Int4 ls32ExecDBPartTransformation( tls00_Command    *pTransformationCmd,
								         tls00_DBInfo     *pDBInfo,
								         tsp00_Addr        ErrText);

#endif //HLS32_DBEXTRACT

/*===========================================================================*
 *     END
 *===========================================================================*/
